@@ -5,10 +5,6 @@ import { Repos } from "./repos.ts";
 const repos = await Repos.load();
 
 for (const crate of repos.getCrates()) {
-  if (crate.name === "eszip_wasm") {
-    continue;
-  }
-
   console.log(`Building ${crate.name}...`);
   await crate.build({ allFeatures: true });
 }
