@@ -6,10 +6,6 @@ const repos = await Repos.load();
 let hadConfirmed = false;
 
 for (const crate of repos.getCrates()) {
-  if (crate.name === "eszip_wasm") {
-    continue;
-  }
-
   if (hadConfirmed || confirm(`Do you want to run tests for ${crate.name}?`)) {
     hadConfirmed = true;
     console.log(`Running tests for ${crate.name}...`);
